.. _overview:

Momoko
======

Momoko wraps Psycopg2_'s functionality for use in Tornado_.

The latest source code can be found on Github_ and bug reports can be sent
there too. All releases will be uploaded to PyPi_.


.. _Psycopg2: http://initd.org/psycopg
.. _Tornado: http://www.tornadoweb.org
.. _Github: https://github.com/FSX/momoko
.. _PyPi: https://pypi.python.org/pypi/Momoko

Contents:

.. toctree::
   :maxdepth: 1

   changelog
   installation
   tutorial
   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`search`

